package accountlogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-member-server/pkg/domain/usecase"
	"code.30cm.net/digimon/library-go/errs"

	"code.30cm.net/digimon/app-cloudep-member-server/gen_result/pb/member"
	"code.30cm.net/digimon/app-cloudep-member-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUIDByAccountLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetUIDByAccountLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUIDByAccountLogic {
	return &GetUIDByAccountLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

type getUIDByAccountReq struct {
	Account string `validate:"required"`
}

// GetUIDByAccount 用帳號換取 UID
func (l *GetUIDByAccountLogic) GetUIDByAccount(in *member.GetUIDByAccountReq) (*member.GetUIDByAccountResp, error) {
	if err := l.svcCtx.Validate.ValidateAll(&getUIDByAccountReq{
		Account: in.GetAccount(),
	}); err != nil {
		return nil, errs.InvalidFormat(err.Error())
	}

	account, err := l.svcCtx.AccountUseCase.GetUIDByAccount(l.ctx, usecase.GetUIDByAccountRequest{
		Account: in.GetAccount(),
	})
	if err != nil {
		return nil, err
	}

	return &member.GetUIDByAccountResp{
		Account: account.Account,
		Uid:     account.UID,
	}, nil
}
